@@ -1,43 +1,44 @@
 use std::collections::BTreeMap;
 
-use bevy_egui::egui::{FontDefinitions, FontFamily, TextStyle};
-
-pub type FontData = std::borrow::Cow<'static, [u8]>;
+use bevy_egui::egui::{FontDefinitions, FontData, FontFamily, TextStyle};
 
 pub fn embedded_fonts(egui_scale_factor: f32) -> FontDefinitions {
-    #[allow(unused)]
-    let mut font_data: BTreeMap<String, FontData> = BTreeMap::new();
-    let mut fonts_for_family = BTreeMap::new();
-    let mut family_and_size = BTreeMap::new();
+    let mut fonts = FontDefinitions::default();
 
     let mut add_font = |name: &str,
-                        bytes: FontData,
+                        font_data: FontData,
                         small: f32,
                         body: f32,
                         button: f32,
                         heading: f32,
                         mono: f32| {
-        font_data.insert(name.to_owned(), bytes);
+        fonts.font_data.insert(name.to_owned(), font_data);
 
-        fonts_for_family.insert(FontFamily::Monospace, vec![name.to_owned()]);
-        fonts_for_family.insert(FontFamily::Proportional, vec![name.to_owned()]);
-        family_and_size.insert(
+        fonts.fonts_for_family
+            .entry(FontFamily::Monospace)
+            .or_default()
+            .insert(0, name.to_owned());
+        fonts.fonts_for_family
+            .entry(FontFamily::Proportional)
+            .or_default()
+            .insert(0, name.to_owned());
+        fonts.family_and_size.insert(
             TextStyle::Small,
             (FontFamily::Proportional, small / egui_scale_factor),
         );
-        family_and_size.insert(
+        fonts.family_and_size.insert(
             TextStyle::Body,
             (FontFamily::Proportional, body / egui_scale_factor),
         );
-        family_and_size.insert(
+        fonts.family_and_size.insert(
             TextStyle::Button,
             (FontFamily::Proportional, button / egui_scale_factor),
         );
-        family_and_size.insert(
+        fonts.family_and_size.insert(
             TextStyle::Heading,
             (FontFamily::Proportional, heading / egui_scale_factor),
         );
-        family_and_size.insert(
+        fonts.family_and_size.insert(
             TextStyle::Monospace,
             (FontFamily::Monospace, mono / egui_scale_factor),
         );
@@ -47,7 +48,7 @@ pub fn embedded_fonts(egui_scale_factor: f32) -> FontDefinitions {
     {
         add_font(
             "NotoSansSC",
-            std::borrow::Cow::Borrowed(include_bytes!("../../fonts/NotoSansSC-Medium.otf")),
+            FontData::from_static(include_bytes!("../../fonts/NotoSansSC-Medium.otf")),
             16.0,
             18.0,
             20.0,
@@ -59,7 +60,7 @@ pub fn embedded_fonts(egui_scale_factor: f32) -> FontDefinitions {
     {
         add_font(
             "FiraMono",
-            std::borrow::Cow::Borrowed(include_bytes!("../../fonts/FiraMono-Medium.ttf")),
+            FontData::from_static(include_bytes!("../../fonts/FiraMono-Medium.ttf")),
             14.0,
             16.0,
             18.0,
@@ -67,10 +68,5 @@ pub fn embedded_fonts(egui_scale_factor: f32) -> FontDefinitions {
             16.0,
         );
     }
-
-    FontDefinitions {
-        font_data,
-        fonts_for_family,
-        family_and_size,
-    }
+    fonts
 }
