@@ -2,7 +2,7 @@ use bevy::prelude::*;
 use bevy_prototype_lyon::prelude::*;
 use notation_bevy_utils::prelude::{BevyUtil, FillRectangle, LayoutSize, ShapeOp};
 
-use crate::prelude::{NotationTheme};
+use crate::prelude::NotationTheme;
 
 #[derive(Clone, Debug)]
 pub struct GuitarCapoData {
@@ -30,10 +30,7 @@ impl ShapeOp<NotationTheme, FillRectangle> for GuitarCapoData {
             BevyUtil::offscreen_offset()
         } else {
             let finger_radius = theme.guitar.string_x_factor * self.guitar_size.width / 2.0;
-            let y = theme
-                .guitar
-                .calc_fret_y(self.capo, self.guitar_size.height)
-                + height * 0.5
+            let y = theme.guitar.calc_fret_y(self.capo, self.guitar_size.height) + height * 0.5
                 - finger_radius;
             Vec3::new(0.0, y, theme.z.guitar_capo)
         };
