@@ -6,20 +6,22 @@ use bevy::prelude::*;
 use notation_bevy_utils::prelude::{
     BevyUtil, LayoutAnchor, LayoutChangedQuery, LayoutSize, ShapeOp, View, ViewBundle,
 };
-use notation_midi::prelude::MidiState;
 use notation_model::prelude::{
     Duration, Entry, HandShape6, Interval, LaneEntry, LaneKind, ModelEntryProps, Pick, Syllable,
     Tab, TrackKind, Units,
 };
 
 use crate::prelude::{EntryPlaying, NotationAssets, NotationSettings, NotationTheme, TabState};
-use crate::ui::layout::NotationLayout;
+use crate::prelude::NotationLayout;
 
 use super::fret_finger::FretFingerData;
 use super::guitar_barre::GuitarBarreData;
 use super::guitar_capo::GuitarCapoData;
 use super::guitar_string::GuitarStringData;
 
+#[cfg(feature = "midi")]
+use notation_midi::prelude::MidiState;
+
 #[derive(Clone, Debug)]
 pub struct GuitarView {
     pub tab: Arc<Tab>,
@@ -181,6 +183,7 @@ impl GuitarView {
         mut commands: Commands,
         assets: Res<NotationAssets>,
         settings: Res<NotationSettings>,
+        #[cfg(feature = "midi")]
         midi_state: Res<MidiState>,
         time: Res<Time>,
         theme: Res<NotationTheme>,
@@ -196,6 +199,9 @@ impl GuitarView {
         if theme._bypass_systems {
             return;
         }
+        if settings.hide_guitar_view {
+            return;
+        }
         let mut current_entry_pick = None;
         let mut string_states = [None; 6];
         let mut hit_strings = [(false, Duration::Zero); 6];
@@ -218,6 +224,7 @@ impl GuitarView {
         for (string_entity, mut string_data) in string_query.iter_mut() {
             if string_data.string >= 1 && string_data.string <= 6 {
                 let (hit, hit_duration) = hit_strings[(string_data.string - 1) as usize];
+                #[cfg(feature = "midi")]
                 string_data.set_hit(
                     hit,
                     hit_duration,
@@ -253,6 +260,7 @@ impl GuitarView {
                         &theme,
                         &settings,
                         finger_entity,
+                        &meta.clone().unwrap_or_default(),
                     );
                 }
             }
@@ -280,6 +288,9 @@ impl GuitarView {
         if theme._bypass_systems {
             return;
         }
+        if settings.hide_guitar_view {
+            return;
+        }
         let mut current_shape = None;
         for (entry, shape, playing) in query.iter() {
             if playing.value.is_current() {
@@ -314,6 +325,7 @@ impl GuitarView {
                     &theme,
                     &settings,
                     finger_entity,
+                    &meta.clone().unwrap_or_default(),
                 );
             }
             for (string_entity, mut string_data) in string_query.iter_mut() {
@@ -398,6 +410,9 @@ impl GuitarView {
         if theme._bypass_systems {
             return;
         }
+        if settings.hide_guitar_view {
+            return;
+        }
         if settings.override_guitar_y.is_some() {
             return;
         }
