@@ -1,6 +1,12 @@
-pub use {notation_midi, notation_model};
+pub use {notation_model};
 
-pub use {bevy, bevy_prototype_lyon};
+#[cfg(feature = "dsl")]
+pub use notation_dsl;
+
+#[cfg(feature = "midi")]
+pub use notation_midi;
+
+pub use {bevy, bevy_prototype_lyon, bevy_egui, bevy_asset_loader};
 
 #[cfg(target_arch = "wasm32")]
 pub use bevy_webgl2;
@@ -20,7 +26,7 @@ pub mod play;
 pub mod tab;
 
 pub mod guitar;
-pub mod help;
+pub mod kb;
 pub mod lyrics;
 pub mod melody;
 pub mod rhythm;
@@ -31,10 +37,7 @@ pub mod data;
 pub mod font;
 pub mod settings;
 pub mod theme;
-
-pub mod app;
-pub mod ui;
-pub mod viewer;
+pub mod notation;
 
 #[cfg(target_arch = "wasm32")]
 pub mod wasm;
@@ -45,18 +48,19 @@ pub mod inspector;
 #[cfg(feature = "dev")]
 pub mod dev;
 
+#[cfg(feature = "midi")]
+pub mod midi;
+
 #[cfg(feature = "dsl")]
 pub mod dsl;
 
 pub mod prelude {
     #[doc(hidden)]
-    pub use crate::app::app::{NotationApp, NotationPlugins};
+    pub use notation_model::prelude::*;
     #[doc(hidden)]
-    pub use crate::app::app_events::*;
+    pub use notation_bevy_utils::prelude::*;
     #[doc(hidden)]
-    pub use crate::app::app_state::{NotationAppState, TabPathes};
-    #[doc(hidden)]
-    pub use crate::app::assets::{NotationAssets, NotationAssetsStates};
+    pub use bevy_asset_loader::{self, AssetCollection};
     #[doc(hidden)]
     pub use crate::bar::bar_bundle::BarBundle;
     #[doc(hidden)]
@@ -134,13 +138,36 @@ pub mod prelude {
     #[doc(hidden)]
     pub use crate::tone::tone_mode::ToneMode;
     #[doc(hidden)]
-    pub use crate::ui::layout::NotationLayout;
+    pub use crate::notation::app::{NotationApp, NotationPlugins};
     #[doc(hidden)]
-    pub use crate::ui::viewer::TabViewer;
+    pub use crate::notation::events::*;
     #[doc(hidden)]
-    pub use crate::ui::NotationUiPlugin;
+    pub use crate::notation::state::{NotationState, TabPathes};
     #[doc(hidden)]
-    pub use crate::viewer::app::NotationViewer;
+    pub use crate::notation::assets::{NotationAssets, NotationAssetsStates, ExtraAssets, NoExtraAssets};
     #[doc(hidden)]
-    pub use notation_bevy_utils::prelude::*;
+    pub use crate::notation::layout::NotationLayout;
+    #[doc(hidden)]
+    pub use crate::notation::tab_viewer::TabViewer;
+    #[doc(hidden)]
+    pub use crate::notation::ui::NotationUiPlugin;
+    #[doc(hidden)]
+    pub use crate::notation::control::Control;
+    #[doc(hidden)]
+    pub use crate::notation::control_panel::ControlPanel;
+    #[doc(hidden)]
+    pub use crate::kb::kb_page::{KbPage, KbPageId, KbContent};
+    #[doc(hidden)]
+    pub use crate::kb::page_helper::PageHelper;
+    #[doc(hidden)]
+    pub use crate::kb::kb_panel::KbPanel;
+    #[cfg(feature = "midi")]
+    #[doc(hidden)]
+    pub use crate::notation_midi::prelude::*;
+    #[cfg(feature = "midi")]
+    #[doc(hidden)]
+    pub use crate::midi::midi_control::MidiControl;
+    #[cfg(feature = "dsl")]
+    #[doc(hidden)]
+    pub use crate::notation_dsl::prelude::*;
 }
