@@ -3,7 +3,7 @@ use bevy::prelude::*;
 use notation_bevy_utils::prelude::{DoLayoutEvent, ShapeOp};
 
 use crate::prelude::{BarPlaying, NotationAssetsStates, NotationTheme};
-use crate::ui::layout::NotationLayout;
+use crate::prelude::NotationLayout;
 
 use super::mini_bar::{MiniBar, MiniBarData};
 use super::mini_map::MiniMap;
