@@ -11,9 +11,9 @@ use notation_model::prelude::Tab;
 use crate::chord::chord_color_background::ChordColorBackground;
 use crate::play::play_panel::PlayPanel;
 use crate::prelude::{
-    GuitarView, NotationAppState, NotationAssets, NotationSettings, NotationTheme,
+    GuitarView, NotationState, NotationAssets, NotationSettings, NotationTheme,
 };
-use crate::ui::layout::NotationLayout;
+use crate::prelude::NotationLayout;
 
 use super::tab_events::TabControlDoLayoutEvent;
 
@@ -32,6 +32,9 @@ impl TabControl {
 }
 impl<'a> View<NotationLayout<'a>> for TabControl {
     fn calc_size(&self, engine: &NotationLayout, constraint: LayoutConstraint) -> LayoutSize {
+        if engine.settings.hide_guitar_view {
+            return LayoutSize::new(0.0, constraint.max.height);
+        }
         let width = match engine.settings.override_guitar_width {
             Some(width) => width,
             None => {
@@ -68,6 +71,9 @@ impl TabControl {
         let control = TabControl::new(tab.clone());
         let control_entity =
             BevyUtil::spawn_child_bundle(commands, entity, ViewBundle::from(control));
+        if settings.hide_guitar_view {
+            return control_entity;
+        }
         ChordColorBackground::spawn(
             commands,
             control_entity,
@@ -83,7 +89,7 @@ impl TabControl {
     pub fn do_layout(
         mut evts: EventReader<TabControlDoLayoutEvent>,
         theme: Res<NotationTheme>,
-        state: Res<NotationAppState>,
+        state: Res<NotationState>,
         settings: Res<NotationSettings>,
         mut layout_query: LayoutQuery,
         panel_query: ViewQuery<PlayPanel>,
